aboutsummaryrefslogtreecommitdiff
path: root/runit
diff options
context:
space:
mode:
authorDenis Vlasenko <vda.linux@googlemail.com>2008-10-31 02:37:18 +0000
committerDenis Vlasenko <vda.linux@googlemail.com>2008-10-31 02:37:18 +0000
commit028eab61bc44f34f27a4fb5cae03b5b6460b024d (patch)
tree44bcd6d2fef18ec18cad7637624992303033b1ab /runit
parentbb26db49b1b3a6cbc4b72c0cc6948432e3e77996 (diff)
downloadbusybox-028eab61bc44f34f27a4fb5cae03b5b6460b024d.tar.gz
runsvdir: if we have PID == 1, SIGHUP should make small pause,
not 1 minute one
Diffstat (limited to 'runit')
-rw-r--r--runit/runsvdir.c5
1 files changed, 3 insertions, 2 deletions
diff --git a/runit/runsvdir.c b/runit/runsvdir.c
index d5e58e9e7..581787f03 100644
--- a/runit/runsvdir.c
+++ b/runit/runsvdir.c
@@ -371,9 +371,10 @@ int runsvdir_main(int argc UNUSED_PARAM, char **argv)
goto ret;
default:
/* so we are init. do not exit,
- * and pause respawning - we may be rebooting... */
+ * and pause respawning - we may be rebooting
+ * (but SIGHUP is not a reboot, make short pause) */
+ deadline = (SIGHUP == bb_got_signal) ? 5 : 60;
bb_got_signal = 0;
- deadline = 60;
goto do_sleep;
}
}